==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/PolarLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarLineSeriesBaseDescriptionMetadata } from "./PolarLineSeriesBaseDescriptionMetadata";
import { PolarLineSeriesDescription } from "./PolarLineSeriesDescription";
/**
 * @hidden
 */
export let PolarLineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class PolarLineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (PolarLineSeriesDescriptionMetadata.a == null) {
                PolarLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PolarLineSeriesDescriptionMetadata.c(PolarLineSeriesDescriptionMetadata.a);
            }
            if (a.k(PolarLineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(PolarLineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            PolarLineSeriesBaseDescriptionMetadata.c(a);
            a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
            a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
        }
        static d(a) {
            PolarLineSeriesDescriptionMetadata.b(a);
            a.ad("PolarLineSeries", () => new PolarLineSeriesDescription());
            a.ac("PolarLineSeries", PolarLineSeriesDescriptionMetadata.a);
        }
    }
    PolarLineSeriesDescriptionMetadata.$t = markType(PolarLineSeriesDescriptionMetadata, 'PolarLineSeriesDescriptionMetadata');
    PolarLineSeriesDescriptionMetadata.a = null;
    return PolarLineSeriesDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/PolarLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarLineSeriesBaseDescriptionMetadata } from "./PolarLineSeriesBaseDescriptionMetadata";
import { PolarLineSeriesDescription } from "./PolarLineSeriesDescription";
/**
 * @hidden
 */
export let PolarLineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class PolarLineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (PolarLineSeriesDescriptionMetadata.a == null) {
                PolarLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PolarLineSeriesDescriptionMetadata.c(PolarLineSeriesDescriptionMetadata.a);
            }
            if (a.k(PolarLineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(PolarLineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            PolarLineSeriesBaseDescriptionMetadata.c(a);
            a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
            a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
        }
        static d(a) {
            PolarLineSeriesDescriptionMetadata.b(a);
            a.ae("PolarLineSeries", () => new PolarLineSeriesDescription());
            a.ad("PolarLineSeries", PolarLineSeriesDescriptionMetadata.a);
        }
    }
    PolarLineSeriesDescriptionMetadata.$t = markType(PolarLineSeriesDescriptionMetadata, 'PolarLineSeriesDescriptionMetadata');
    PolarLineSeriesDescriptionMetadata.a = null;
    return PolarLineSeriesDescriptionMetadata;
})();
